@@ -266,7 +266,7 @@ eog_job_load_class_init (EogJobLoadClass *class)
 }
 
 EogJob *
-eog_job_load_new (EogImage *image)
+eog_job_load_new (EogImage *image, EogImageData data)
 {
 	EogJobLoad *job;
 
@@ -275,6 +275,7 @@ eog_job_load_new (EogImage *image)
 	if (image) {
 		job->image = g_object_ref (image);
 	}
+	job->data = data;
 
 	return EOG_JOB (job);
 }
@@ -290,7 +291,7 @@ eog_job_load_run (EogJobLoad *job)
 	}
 
 	eog_image_load (EOG_IMAGE (job->image),
-			EOG_IMAGE_DATA_ALL,
+			job->data,
 			EOG_JOB (job),
 			&EOG_JOB (job)->error);
 
@@ -345,12 +346,26 @@ filter_files (GSList *files, GList **file_list, GList **error_list)
 
 		if (file != NULL) {
 			file_info = g_file_query_info (file,
-						       G_FILE_ATTRIBUTE_STANDARD_TYPE,
+						       G_FILE_ATTRIBUTE_STANDARD_TYPE","G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
 						       0, NULL, NULL);
 			if (file_info == NULL) {
 				type = G_FILE_TYPE_UNKNOWN;
 			} else {
 				type = g_file_info_get_file_type (file_info);
+
+				/* Workaround for gvfs backends that
+				   don't set the GFileType. */
+				if (G_UNLIKELY (type == G_FILE_TYPE_UNKNOWN)) {
+					const gchar *ctype;
+			
+					ctype = g_file_info_get_content_type (file_info);
+
+					/* If the content type is supported
+					   adjust the file_type */
+					if (eog_image_is_supported_mime_type (ctype))
+						type = G_FILE_TYPE_REGULAR;
+				}
+
 				g_object_unref (file_info);
 			}
 		}
@@ -390,6 +405,9 @@ eog_job_model_run (EogJobModel *job)
 	g_list_foreach (filtered_list, (GFunc) g_object_unref, NULL);
 	g_list_free (filtered_list);
 
+	g_list_foreach (error_list, (GFunc) g_free, NULL);
+	g_list_free (error_list);
+
 	EOG_JOB (job)->finished = TRUE;
 }
 
